@@ -3,7 +3,7 @@ import datetime
 import gc
 import re
 import sys
-from collections import defaultdict
+from collections import OrderedDict, defaultdict
 from typing import Any, Optional, Tuple, Union
 
 from ..key import get_template_and_func_for
@@ -132,10 +132,9 @@ class Memory(Backend):
     def _count_get(self, key):
         if not self._count_stat:
             return
-        template_and_func = get_template_and_func_for(key)
-        if not template_and_func:
+        template, _ = get_template_and_func_for(key)
+        if template is None:
             return
-        template, _ = template_and_func
 
         if key in self.store:
             self._counters[template]["hit"] += 1
@@ -145,10 +144,9 @@ class Memory(Backend):
     def _count_set(self, key):
         if not self._count_stat:
             return
-        template_and_func = get_template_and_func_for(key)
-        if not template_and_func:
+        template, _ = get_template_and_func_for(key)
+        if template is None:
             return
-        template, _ = template_and_func
         self._counters[template]["set"] += 1
 
 
@@ -186,7 +184,7 @@ class MemoryInterval(Memory):
 
     async def get_expire(self, key: str) -> int:
         if key in self._meta:
-            return abs(float((datetime.datetime.utcnow() - self._meta[key]).total_seconds()))
+            return abs(int((datetime.datetime.utcnow() - self._meta[key]).total_seconds()))
         return -1
 
     async def clear(self):
