@@ -3,12 +3,14 @@ import os
 from unittest.mock import Mock
 
 import pytest
+
 from cashews import decorators
 from cashews.backends.memory import Backend, Memory
 from cashews.backends.redis import Redis
 
 pytestmark = pytest.mark.asyncio
-EXPIRE = 0.01
+REDIS_TESTS = bool(os.environ.get("USE_REDIS"))
+EXPIRE = 0.02
 
 
 class CustomError(Exception):
@@ -17,7 +19,7 @@ class CustomError(Exception):
 
 @pytest.fixture()
 async def backend():
-    if os.environ.get("USE_REDIS"):
+    if REDIS_TESTS:
         redis = Redis("redis://", hash_key=None)
         await redis.init()
         await redis.clear()
@@ -38,7 +40,7 @@ async def test_fail_cache_simple(backend):
     await asyncio.sleep(0.001)
     assert await func(fail=True) == b"ok"
 
-    await asyncio.sleep(EXPIRE)
+    await asyncio.sleep(EXPIRE * 1.1)
     with pytest.raises(CustomError):
         await func(fail=True)
 
@@ -74,7 +76,7 @@ async def test_cache_simple(backend):
     await asyncio.sleep(0)
     assert await func(b"notok") == b"ok"
 
-    await asyncio.sleep(EXPIRE)
+    await asyncio.sleep(EXPIRE * 1.1)
     assert await func(b"notok") == b"notok"
 
 
@@ -104,9 +106,7 @@ async def test_cache_simple_key(backend):
 
     assert await func() == b"ok"
     assert await func(b"notok", some="test") == b"notok"
-
     assert await func(b"notok") == b"ok"
-
     assert await func2(b"notok") == b"notok"
 
 
@@ -119,7 +119,6 @@ async def test_cache_simple_cond(backend):
         return resp
 
     await func()
-
     assert mock.call_count == 1
 
     await func(b"notok")
@@ -141,41 +140,51 @@ async def test_early_cache_simple(backend):
     await asyncio.sleep(0)
     assert await func(b"notok") == b"ok"
 
-    await asyncio.sleep(EXPIRE)
+    await asyncio.sleep(EXPIRE * 1.1)
     assert await func(b"notok") == b"notok"
 
 
+@pytest.mark.skipif(REDIS_TESTS, reason="only for mem")
 async def test_early_cache_parallel(backend):
 
     mock = Mock()
 
-    @decorators.early(backend, ttl=0.1, key="key")
+    @decorators.early(backend, ttl=0.1, early_ttl=0.05, key="key")
     async def func(resp=b"ok"):
         await asyncio.sleep(0.01)
         mock(resp)
         return resp
 
-    assert await func() == b"ok"
+    assert await func() == b"ok"  # warm
 
     assert mock.call_count == 1
 
-    for _ in range(4):  # 0.01 (first) + 4 * 0.01 = 0.06 + 0.01(executing) 0.8 will execute
+    for _ in range(8):  # 8 * 0.01 = 0.08 - 1 more time should be executed
         await asyncio.sleep(0.01)
         await asyncio.gather(*[func() for _ in range(10)])
 
-    assert mock.call_count == 1
-
-    for _ in range(60):  # 0.01 (hit) + 60 * 0.001  = 0.07 - next hit
-        await asyncio.sleep(0.001)
-        await asyncio.gather(*[func() for _ in range(10)])
-
-    assert mock.call_count in [3, 4, 5]
+    assert mock.call_count == 2
 
 
 async def test_lock_cache_parallel(backend):
     mock = Mock()
 
     @decorators.locked(backend, key="key", step=0.01)
+    async def func(resp=b"ok"):
+        await asyncio.sleep(0.1)
+        mock(resp)
+        return resp
+
+    for _ in range(4):
+        await asyncio.gather(*[func() for _ in range(10)], return_exceptions=True)
+
+    assert mock.call_count == 4
+
+
+async def test_lock_cache_parallel_ttl(backend):
+    mock = Mock()
+
+    @decorators.locked(backend, key="key", step=0.01, ttl=0.1)
     async def func(resp=b"ok"):
         await asyncio.sleep(0.01)
         mock(resp)
@@ -184,7 +193,7 @@ async def test_lock_cache_parallel(backend):
     for _ in range(4):
         await asyncio.gather(*[func() for _ in range(10)], return_exceptions=True)
 
-    assert mock.call_count == 4
+    assert mock.call_count == 40
 
 
 async def test_lock_cache_broken_backend():
@@ -256,10 +265,10 @@ async def test_perf_cache(backend):
     with pytest.raises(decorators.PerfDegradationException):
         await func(0.001)  # long
         assert mock.call_count == 11
-
+    await asyncio.sleep(0.05)
     # prev was slow so no hits
     with pytest.raises(decorators.PerfDegradationException):
-        await asyncio.gather(*[func() for _ in range(1000)])
+        await asyncio.gather(*[func() for _ in range(100)])
 
     assert mock.call_count == 11
     await asyncio.sleep(0.2)
@@ -281,7 +290,7 @@ async def test_cache_detect_simple(backend):
     assert await func(b"notok", _from_cache=cache_detect) == b"ok"
     assert len(cache_detect.get()) == 1
     assert list(cache_detect.get().keys()) == [
-        f"key:{EXPIRE}",
+        "key",
     ]
 
 
@@ -298,10 +307,10 @@ async def test_context_cache_detect_simple(backend):
     assert await func(b"notok") == b"ok"
     assert len(decorators.context_cache_detect.get()) == 1
     assert list(decorators.context_cache_detect.get().keys()) == [
-        f"key:{EXPIRE}",
+        "key",
     ]
 
-    await asyncio.sleep(EXPIRE)
+    await asyncio.sleep(EXPIRE * 1.1)
     assert await func(b"notok") == b"notok"
     assert len(decorators.context_cache_detect.get()) == 1
 
@@ -326,8 +335,8 @@ async def test_context_cache_detect_deep(backend):
     await func()
 
     assert len(decorators.context_cache_detect.get()) == 2
-    assert f"key1:{EXPIRE}" in decorators.context_cache_detect.get()
-    assert f"key2:{EXPIRE}" in decorators.context_cache_detect.get()
+    assert "key1" in decorators.context_cache_detect.get()
+    assert "key2" in decorators.context_cache_detect.get()
 
 
 async def test_context_cache_detect_context(backend):
@@ -346,8 +355,8 @@ async def test_context_cache_detect_context(backend):
         res = await asyncio.gather(*funcs)
         return len(decorators.context_cache_detect.get())
 
-    await backend.set(f"key1:{EXPIRE}", "test")
-    await backend.set(f"key2:{EXPIRE}", "test")
+    await backend.set(f"key1", "test")
+    await backend.set(f"key2", "test")
     assert await func1() == "test"
     assert await func2() == "test"
 
