@@ -5,6 +5,7 @@ from datetime import date, datetime, timedelta
 from decimal import Decimal
 
 import pytest
+
 from cashews.backends.redis import Redis
 from cashews.serialize import PickleSerializerMixin, UnSecureDataError
 
@@ -49,8 +50,7 @@ async def _cache():
         await redis.init()
         await redis.clear()
         return redis
-    cache = Cache()
-    cache._hash_key = b"test"
+    cache = Cache(hash_key="test", digestmod="md5")
     return cache
 
 
@@ -119,6 +119,13 @@ async def test_unsecure_value(cache):
     assert not await cache.get_row("key")
 
 
+async def test_unsecure_value_many(cache):
+    await cache.set_row("key", b"cos\nsystem\n(S'echo hello world'\ntR.")
+    with pytest.raises(UnSecureDataError):
+        await cache.get_many("key")
+    assert not await cache.get_row("key")
+
+
 async def test_no_value(cache):
     assert await cache.get("key") is None
 
